==> SD35B_0.03.0_src.tar.gz: Sd35b/decoder/CommandDriverC.cpp <==
/*
 * CommandDriverC.cpp
 *		- "ALICE SOFT System3.x" compatible scenario decoder SD35
 *
 * Copyright (C) 1999 Atsushi Mizuguchi  All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA
 * 
 * 
 *      99/05/24 KISAKA Toshihiro       modify for mwcc compatiblility
 *
 */

#include "stdafx.h"
#include "CommandDriver.h"

#include "ScenarioDecoder.h"
#include "ScenarioParser.h"
#include "ExpressionDriver.h"
#include "GraphicDriver.h"

#if (!__MWERKS__ || defined(MSIPL_USING_NAMESPACE))
using namespace ALSD;
using namespace ALSD_CMDDRV;
#endif
/**********************************************************************
	C command
**********************************************************************/
void CCommandDriver::_CommandC(void)
{
	long Cmd = m_lpSD->GetParser()->GetC();
	(this->*m_lpCmdFuncTblC[Cmd-'A'])();
}

/**********************************************************************
	``
**********************************************************************/
void CCommandDriver::CommandCB( void )
{
	long sx = m_lpED->GetExpValue();
	long sy = m_lpED->GetExpValue();
	long w	= m_lpED->GetExpValue();
	long h	= m_lpED->GetExpValue();
	long color	 = m_lpED->GetExpValue();

	m_lpGD->StrokeRect( sx, sy, w, h, color );
	m_lpGD->OnDraw ( sx, sy, w, h );

	TRACE( "command:CB(...)\n" );	
}
/**********************************************************************
	Rs[
**********************************************************************/
void CCommandDriver::CommandCC( void )
{
	long sx = m_lpED->GetExpValue();
	long sy = m_lpED->GetExpValue();
	long w	= m_lpED->GetExpValue();
	long h	= m_lpED->GetExpValue();
	long dx = m_lpED->GetExpValue();
	long dy = m_lpED->GetExpValue();

	m_lpGD->BltFast( sx, sy, w, h, dx, dy );
	m_lpGD->OnDraw ( dx, dy, w, h );
#ifdef _DEBUG
	TRACE( "command:CC( %d, %d, %d, %d, %d, %d )\n", sx, sy, w, h, dx, dy );
#endif
}
/**********************************************************************
	GtFNgXvCgtRs[
**********************************************************************/
void CCommandDriver::CommandCD( void )
{
	long sx = m_lpED->GetExpValue();
	long sy = m_lpED->GetExpValue();
	long w	= m_lpED->GetExpValue();
	long h	= m_lpED->GetExpValue();
	long dx = m_lpED->GetExpValue();
	long dy = m_lpED->GetExpValue();
	long ef	= m_lpED->GetExpValue();
	long op	= m_lpED->GetExpValue();
	long wf = m_lpED->GetExpValue();
	long c	= m_lpED->GetExpValue();

	m_lpGD->BltEffect( sx, sy, w, h, dx, dy, ef, op, wf, c );
	m_lpGD->OnDraw ( dx, dy, w, h );
	TRACE( "error:[Half] implement... /" );
	TRACE( "command:CD(...)\n" );
}
/**********************************************************************
	GtFNgtRs[
**********************************************************************/
void CCommandDriver::CommandCE( void )
{
	long sx = m_lpED->GetExpValue();
	long sy = m_lpED->GetExpValue();
	long w	= m_lpED->GetExpValue();
	long h	= m_lpED->GetExpValue();
	long dx = m_lpED->GetExpValue();
	long dy = m_lpED->GetExpValue();
	long ef	= m_lpED->GetExpValue();
	long op	= m_lpED->GetExpValue();
	long wf = m_lpED->GetExpValue();

	m_lpGD->BltEffect( sx, sy, w, h, dx, dy, ef, op, wf, -1 );
	m_lpGD->OnDraw ( dx, dy, w, h );
	TRACE( "error:[Half] implement... /" );
	TRACE( "command:CE(...)\n" );	
}
/**********************************************************************
	`hԂ
**********************************************************************/
void CCommandDriver::CommandCF( void )
{
	long x	= m_lpED->GetExpValue();
	long y	= m_lpED->GetExpValue();
	long w	= m_lpED->GetExpValue();
	long h	= m_lpED->GetExpValue();
	long c	= m_lpED->GetExpValue();

	m_lpGD->FillRect( x, y, w, h, c );
	m_lpGD->OnDraw( x, y, w, h );
	TRACE( "command:CF(...)\n" );	
}
/**********************************************************************
	w͈͂ɐFd˂
**********************************************************************/
void CCommandDriver::CommandCK( void )
{
	long no = m_lpSD->GetParser()->GetC();
	long x	= m_lpED->GetExpValue();
	long y	= m_lpED->GetExpValue();
	long w	= m_lpED->GetExpValue();
	long h	= m_lpED->GetExpValue();
	long a1 = m_lpED->GetExpValue();
	long a2= m_lpED->GetExpValue();
	long a3=m_lpED->GetExpValue();
	long a4	= m_lpED->GetExpValue();

	TRACE( "error:[Half] implement... /" );
	switch( no ){
		case 1: // Fd˂
			if( a2 == 255 ){
				m_lpGD->FillRect( x, y, w, h, a1 );
				m_lpGD->OnDraw( x, y, w, h );
			}else{
				m_lpGD->AddColorRect( x, y, w, h, a1, a2 );
				m_lpGD->OnDraw( x, y, w, h );
			}
			break;
		case 2: // Ԋ|
			m_lpGD->AddColorRect( x, y, w, h, a3, 128 );
			m_lpGD->OnDraw( x, y, w, h );
			TRACE("[CK 2/Ԋ|][Dummy]Implement/" );			
			break;
		case 3:	// WrbgFύX
			TRACE("[CK 3/FύX][No]Implement/" );			
			break;
	}
	TRACE( "command:CK(...)\n" );	
}
/**********************************************************************
	`
**********************************************************************/
void CCommandDriver::CommandCL( void )
{
	long x0	= m_lpED->GetExpValue();
	long y0	= m_lpED->GetExpValue();
	long x1	= m_lpED->GetExpValue();
	long y1	= m_lpED->GetExpValue();
	long c	= m_lpED->GetExpValue();

	m_lpGD->StrokeLine( x0, y0, x1, y1, c );
	
	long w, h;
	if( x0 > x1 ){
		w = x0 - x1;
	}else{
		w = x1 - x0;
	}
	if( y0 > y1 ){
		h = y0 - y1;
	}else{
		h = y1 - y0;
	}
	m_lpGD->OnDraw( x0, y0, w, h );

	TRACE( "command:CL(...)\n" );	
}
/**********************************************************************
	gEkE]Rs[
**********************************************************************/
void CCommandDriver::CommandCM( void )
{
	long sx = m_lpED->GetExpValue();
	long sy = m_lpED->GetExpValue();
	long sw	= m_lpED->GetExpValue();
	long sh	= m_lpED->GetExpValue();
	long dx = m_lpED->GetExpValue();
	long dy = m_lpED->GetExpValue();
	long dw	= m_lpED->GetExpValue();
	long dh	= m_lpED->GetExpValue();
	long ms	= m_lpED->GetExpValue();

	stGrpRect SrcRect;
	stGrpRect DstRect;

	SrcRect.left	= sx;
	SrcRect.top		= sy;
	SrcRect.right	= sx + sw;
	SrcRect.bottom	= sy + sh;

	DstRect.left	= dx;
	DstRect.top		= dy;
	DstRect.right	= dx + dw;
	DstRect.bottom	= dy + dh;

	m_lpGD->BltMirror( &SrcRect, &DstRect, ms );
	m_lpGD->OnDraw( dx, dy, dw, dh );
	TRACE( "command:CM(...)\n" );	
}
/**********************************************************************
	yCg
**********************************************************************/
void CCommandDriver::CommandCP( void )
{
	long x	= m_lpED->GetExpValue();
	long y	= m_lpED->GetExpValue();
	long c	= m_lpED->GetExpValue();

	TRACE( "error:[Dummy] implement... /" );
	TRACE( "command:CP(...)\n" );	
}
/**********************************************************************
	8bitpXvCgRs[
**********************************************************************/
void CCommandDriver::CommandCS( void )
{
	long sx = m_lpED->GetExpValue();
	long sy = m_lpED->GetExpValue();
	long w	= m_lpED->GetExpValue();
	long h	= m_lpED->GetExpValue();
	long dx = m_lpED->GetExpValue();
	long dy = m_lpED->GetExpValue();
	long sp	= m_lpED->GetExpValue();

	m_lpGD->BltSprite( sx, sy, w, h, dx, dy, sp );
	m_lpGD->OnDraw( dx, dy, w, h );
	TRACE( "command:CS(...)\n" );	
}
/**********************************************************************
	ef[^擾
**********************************************************************/
void CCommandDriver::CommandCT( void )
{
	long*var= m_lpED->GetVariable();
	long x	= m_lpED->GetExpValue();
	long y	= m_lpED->GetExpValue();

	TRACE( "error:[Dummy] implement... /" );
	TRACE( "command:CU(...)\n" );	
}
/**********************************************************************
	ef[^`̈ϊ
**********************************************************************/
void CCommandDriver::CommandCU( void )
{
	long sx = m_lpED->GetExpValue();
	long sy = m_lpED->GetExpValue();
	long w	= m_lpED->GetExpValue();
	long h	= m_lpED->GetExpValue();
	long border	= m_lpED->GetExpValue();
	long set	= m_lpED->GetExpValue();

	TRACE( "error:[Dummy] implement... /" );
	TRACE( "command:CU(...)\n" );	
}
/**********************************************************************
	ef[^`̈ϊ
**********************************************************************/
void CCommandDriver::CommandCV( void )
{
	long sx = m_lpED->GetExpValue();
	long sy = m_lpED->GetExpValue();
	long w	= m_lpED->GetExpValue();
	long h	= m_lpED->GetExpValue();
	long border	= m_lpED->GetExpValue();
	long set	= m_lpED->GetExpValue();

	TRACE( "error:No implement... /" );
	TRACE( "command:CV(...)\n" );	
}
/**********************************************************************
	16BITȏp̃XvCgRs[i\)
**********************************************************************/
void CCommandDriver::CommandCX( void )
{
	long mode=m_lpED->GetExpValue();
	long sx = m_lpED->GetExpValue();
	long sy = m_lpED->GetExpValue();
	long w	= m_lpED->GetExpValue();
	long h	= m_lpED->GetExpValue();
	long dx = m_lpED->GetExpValue();
	long dy = m_lpED->GetExpValue();
	long c	= m_lpED->GetExpValue();

	switch( mode ){
		case 0:
			m_lpGD->BltWithAlpha( sx, sy, w, h, dx, dy );
			break;
		case 1:
			m_lpGD->BltSprite( sx, sy, w, h, dx, dy, c );
			break;
		default:
			m_lpGD->BltFast( sx, sy, w, h, dx, dy );
			TRACE( "error:No implement... /" );
			break;
	}
	m_lpGD->OnDraw ( dx, dy, w, h );

	TRACE( "command:CX(...)\n" );	
}

==> SD35B_0.03.1_src.tar.gz: Sd35b/decoder/CommandDriverC.cpp <==
/*
 * CommandDriverC.cpp
 *		- "ALICE SOFT System3.x" compatible scenario decoder SD35
 *
 * Copyright (C) 1999 Atsushi Mizuguchi  All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA
 * 
 * 
 *      99/05/24 KISAKA Toshihiro       modify for mwcc compatiblility
 *
 */

#include "stdafx.h"
#include "CommandDriver.h"

#include "ScenarioDecoder.h"
#include "ScenarioParser.h"
#include "ExpressionDriver.h"
#include "GraphicDriver.h"

#if (!__MWERKS__ || defined(MSIPL_USING_NAMESPACE))
using namespace ALSD;
using namespace ALSD_CMDDRV;
#endif
/**********************************************************************
	C command
**********************************************************************/
void CCommandDriver::_CommandC(void)
{
	long Cmd = m_lpSD->GetParser()->GetC();
	(this->*m_lpCmdFuncTblC[Cmd-'A'])();
}

/**********************************************************************
	``
**********************************************************************/
void CCommandDriver::CommandCB( void )
{
	long sx = m_lpED->GetExpValue();
	long sy = m_lpED->GetExpValue();
	long w	= m_lpED->GetExpValue();
	long h	= m_lpED->GetExpValue();
	long color	 = m_lpED->GetExpValue();

	m_lpGD->StrokeRect( sx, sy, w, h, color );
	m_lpGD->OnDraw ( sx, sy, w, h );

	TRACE( "command:CB(...)\n" );	
}
/**********************************************************************
	Rs[
**********************************************************************/
void CCommandDriver::CommandCC( void )
{
	long sx = m_lpED->GetExpValue();
	long sy = m_lpED->GetExpValue();
	long w	= m_lpED->GetExpValue();
	long h	= m_lpED->GetExpValue();
	long dx = m_lpED->GetExpValue();
	long dy = m_lpED->GetExpValue();

	m_lpGD->BltFast( sx, sy, w, h, dx, dy );
	m_lpGD->OnDraw ( dx, dy, w, h );
#ifdef _DEBUG
	TRACE( "command:CC( %d, %d, %d, %d, %d, %d )\n", sx, sy, w, h, dx, dy );
#endif
}
/**********************************************************************
	GtFNgXvCgtRs[
**********************************************************************/
void CCommandDriver::CommandCD( void )
{
	long sx = m_lpED->GetExpValue();
	long sy = m_lpED->GetExpValue();
	long w	= m_lpED->GetExpValue();
	long h	= m_lpED->GetExpValue();
	long dx = m_lpED->GetExpValue();
	long dy = m_lpED->GetExpValue();
	long ef	= m_lpED->GetExpValue();
	long op	= m_lpED->GetExpValue();
	long wf = m_lpED->GetExpValue();
	long c	= m_lpED->GetExpValue();

	m_lpGD->BltEffect( sx, sy, w, h, dx, dy, ef, op, wf, c );
	m_lpGD->OnDraw ( dx, dy, w, h );
	TRACE( "error:[Half] implement... /" );
	TRACE( "command:CD(...)\n" );
}
/**********************************************************************
	GtFNgtRs[
**********************************************************************/
void CCommandDriver::CommandCE( void )
{
	long sx = m_lpED->GetExpValue();
	long sy = m_lpED->GetExpValue();
	long w	= m_lpED->GetExpValue();
	long h	= m_lpED->GetExpValue();
	long dx = m_lpED->GetExpValue();
	long dy = m_lpED->GetExpValue();
	long ef	= m_lpED->GetExpValue();
	long op	= m_lpED->GetExpValue();
	long wf = m_lpED->GetExpValue();

	m_lpGD->BltEffect( sx, sy, w, h, dx, dy, ef, op, wf, -1 );
	m_lpGD->OnDraw ( dx, dy, w, h );
	TRACE( "error:[Half] implement... /" );
	TRACE( "command:CE(ef = %d)\n", ef );	
}
/**********************************************************************
	`hԂ
**********************************************************************/
void CCommandDriver::CommandCF( void )
{
	long x	= m_lpED->GetExpValue();
	long y	= m_lpED->GetExpValue();
	long w	= m_lpED->GetExpValue();
	long h	= m_lpED->GetExpValue();
	long c	= m_lpED->GetExpValue();

	m_lpGD->FillRect( x, y, w, h, c );
	m_lpGD->OnDraw( x, y, w, h );
	TRACE( "command:CF(...)\n" );	
}
/**********************************************************************
	w͈͂ɐFd˂
**********************************************************************/
void CCommandDriver::CommandCK( void )
{
	long no = m_lpSD->GetParser()->GetC();
	long x	= m_lpED->GetExpValue();
	long y	= m_lpED->GetExpValue();
	long w	= m_lpED->GetExpValue();
	long h	= m_lpED->GetExpValue();
	long a1 = m_lpED->GetExpValue();
	long a2= m_lpED->GetExpValue();
	long a3=m_lpED->GetExpValue();
	long a4	= m_lpED->GetExpValue();

	TRACE( "error:[Half] implement... /" );
	switch( no ){
		case 1: // Fd˂
			if( a2 == 255 ){
				m_lpGD->FillRect( x, y, w, h, a1 );
				m_lpGD->OnDraw( x, y, w, h );
			}else{
				m_lpGD->AddColorRect( x, y, w, h, a1, a2 );
				m_lpGD->OnDraw( x, y, w, h );
			}
			break;
		case 2: // Ԋ|
			m_lpGD->AddColorRect( x, y, w, h, a3, 128 );
			m_lpGD->OnDraw( x, y, w, h );
			TRACE("[CK 2/Ԋ|][Dummy]Implement/" );			
			break;
		case 3:	// WrbgFύX
			TRACE("[CK 3/FύX][No]Implement/" );			
			break;
	}
	TRACE( "command:CK(...)\n" );	
}
/**********************************************************************
	`
**********************************************************************/
void CCommandDriver::CommandCL( void )
{
	long x0	= m_lpED->GetExpValue();
	long y0	= m_lpED->GetExpValue();
	long x1	= m_lpED->GetExpValue();
	long y1	= m_lpED->GetExpValue();
	long c	= m_lpED->GetExpValue();

	m_lpGD->StrokeLine( x0, y0, x1, y1, c );
	
	long w, h;
	if( x0 > x1 ){
		w = x0 - x1;
	}else{
		w = x1 - x0;
	}
	if( y0 > y1 ){
		h = y0 - y1;
	}else{
		h = y1 - y0;
	}
	m_lpGD->OnDraw( x0, y0, w, h );

	TRACE( "command:CL(...)\n" );	
}
/**********************************************************************
	gEkE]Rs[
**********************************************************************/
void CCommandDriver::CommandCM( void )
{
	long sx = m_lpED->GetExpValue();
	long sy = m_lpED->GetExpValue();
	long sw	= m_lpED->GetExpValue();
	long sh	= m_lpED->GetExpValue();
	long dx = m_lpED->GetExpValue();
	long dy = m_lpED->GetExpValue();
	long dw	= m_lpED->GetExpValue();
	long dh	= m_lpED->GetExpValue();
	long ms	= m_lpED->GetExpValue();

	stGrpRect SrcRect;
	stGrpRect DstRect;

	SrcRect.left	= sx;
	SrcRect.top		= sy;
	SrcRect.right	= sx + sw;
	SrcRect.bottom	= sy + sh;

	DstRect.left	= dx;
	DstRect.top		= dy;
	DstRect.right	= dx + dw;
	DstRect.bottom	= dy + dh;

	m_lpGD->BltMirror( &SrcRect, &DstRect, ms );
	m_lpGD->OnDraw( dx, dy, dw, dh );
	TRACE( "command:CM(...)\n" );	
}
/**********************************************************************
	yCg
**********************************************************************/
void CCommandDriver::CommandCP( void )
{
	long x	= m_lpED->GetExpValue();
	long y	= m_lpED->GetExpValue();
	long c	= m_lpED->GetExpValue();

	TRACE( "error:[Dummy] implement... /" );
	TRACE( "command:CP(...)\n" );	
}
/**********************************************************************
	8bitpXvCgRs[
**********************************************************************/
void CCommandDriver::CommandCS( void )
{
	long sx = m_lpED->GetExpValue();
	long sy = m_lpED->GetExpValue();
	long w	= m_lpED->GetExpValue();
	long h	= m_lpED->GetExpValue();
	long dx = m_lpED->GetExpValue();
	long dy = m_lpED->GetExpValue();
	long sp	= m_lpED->GetExpValue();

	// }}ggΉ
#if (!__MWERKS__ || defined(MSIPL_USING_NAMESPACE))
	ALSD_OFFSCR::stGrpScreenDesc desc = m_lpGD->GetScreen()->GetDesc();
#else
	stGrpScreenDesc	desc = m_lpGD->GetScreen()->GetDesc();
#endif
	if( desc.dwHeight < sy ){
		return ;
	}

	m_lpGD->BltSprite( sx, sy, w, h, dx, dy, sp );
	m_lpGD->OnDraw( dx, dy, w, h );
	TRACE( "command:CS(...)\n" );	
}
/**********************************************************************
	ef[^擾
**********************************************************************/
void CCommandDriver::CommandCT( void )
{
	long*var= m_lpED->GetVariable();
	long x	= m_lpED->GetExpValue();
	long y	= m_lpED->GetExpValue();

	TRACE( "error:[Dummy] implement... /" );
	TRACE( "command:CU(...)\n" );	
}
/**********************************************************************
	ef[^`̈ϊ
**********************************************************************/
void CCommandDriver::CommandCU( void )
{
	long sx = m_lpED->GetExpValue();
	long sy = m_lpED->GetExpValue();
	long w	= m_lpED->GetExpValue();
	long h	= m_lpED->GetExpValue();
	long border	= m_lpED->GetExpValue();
	long set	= m_lpED->GetExpValue();

	TRACE( "error:[Dummy] implement... /" );
	TRACE( "command:CU(...)\n" );	
}
/**********************************************************************
	ef[^`̈ϊ
**********************************************************************/
void CCommandDriver::CommandCV( void )
{
	long sx = m_lpED->GetExpValue();
	long sy = m_lpED->GetExpValue();
	long w	= m_lpED->GetExpValue();
	long h	= m_lpED->GetExpValue();
	long border	= m_lpED->GetExpValue();
	long set	= m_lpED->GetExpValue();

	TRACE( "error:No implement... /" );
	TRACE( "command:CV(...)\n" );	
}
/**********************************************************************
	16BITȏp̃XvCgRs[i\)
**********************************************************************/
void CCommandDriver::CommandCX( void )
{
	long mode=m_lpED->GetExpValue();
	long sx = m_lpED->GetExpValue();
	long sy = m_lpED->GetExpValue();
	long w	= m_lpED->GetExpValue();
	long h	= m_lpED->GetExpValue();
	long dx = m_lpED->GetExpValue();
	long dy = m_lpED->GetExpValue();
	long c	= m_lpED->GetExpValue();

	switch( mode ){
		case 0:
			m_lpGD->BltWithAlpha( sx, sy, w, h, dx, dy );
			break;
		case 1:
			m_lpGD->BltSprite( sx, sy, w, h, dx, dy, c );
			break;
		default:
			m_lpGD->BltFast( sx, sy, w, h, dx, dy );
			TRACE( "error:No implement... /" );
			break;
	}
	m_lpGD->OnDraw ( dx, dy, w, h );

	TRACE( "command:CX(...)\n" );	
}
